@@ -1,18 +1,16 @@
-import munch
 import os
-import oyaml as yaml
 import re
-import requests
-import sys
 import shutil
-import tempfile
-
-from base64 import b64encode, b64decode
+import sys
 from os import mkdir
 from os.path import isfile, realpath, exists, dirname
 from pathlib import Path
-from shutil import copyfile, copy2
+from shutil import copyfile
 
+import munch
+import oyaml as yaml
+import requests
+from cloudmesh.common.FlatDict import FlatDict
 from cloudmesh.common.FlatDict import flatten
 from cloudmesh.common.Shell import Shell
 from cloudmesh.common.console import Console
@@ -20,61 +18,17 @@ from cloudmesh.common.dotdict import dotdict
 from cloudmesh.common.util import backup_name
 from cloudmesh.common.util import banner
 from cloudmesh.common.util import path_expand
-from cloudmesh.common.util import readfile
 from cloudmesh.common.util import writefile
-from cloudmesh.common.util import writefd
 from cloudmesh.common.variables import Variables
-from cloudmesh.common.FlatDict import FlatDict
 from cloudmesh.configuration import __version__ as cloudmesh_yaml_version
-from pathlib import Path
-
-#
-# we sould freeze the cloudmesh.yaml name and just make dir changable
-#
-
-class Location:
-    _shared_state = None
-
-    def __init__(self, directory="~/.cloudmesh"):
-        if not Location._shared_state:
-            self.key = "CLOUDMESH_CONFIG_DIR"
-
-            Location._shared_state = self.__dict__
-            directory = path_expand(directory)
-            self.directory = os.environ.get(self.key) or directory
-        else:
-            self.__dict__ = Location._shared_state
-
-    def get(self):
-        return self.directory
-
-    def set(self, directory):
-        self.directory = path_expand(directory)
-
-    def config(self):
-        p = Path(self.directory) / "cloudmesh.yaml"
-        return p
-
-    def environment(self, key):
-        if key in os.environ:
-            value = os.environ[key]
-            self.set(value)
-        else:
-            Console.error(f"Config location: could not find {key}")
-            return None
-
-    def __str__(self):
-        return self.directory
-
-    def __eq__(self, other):
-        return self.directory == other
+from cloudmesh.common.location import Location
 
 # see also https://github.com/cloudmesh/client/blob/master/cloudmesh_client/cloud/register.py
 
 class Active(object):
 
-    def __init__(self, config_path='~/.cloudmesh/cloudmesh.yaml'):
-        self.config = Config(config_path=config_path)
+    def __init__(self):
+        self.config = Config()
 
     def clouds(self):
         names = []
@@ -143,6 +97,7 @@ class Config(object):
             "private_key_id",
             "private_key",
             "client_id",
+            "client_email",
             "client_x509_cert_url",
             "auth__password",
             "auth.password"
@@ -201,7 +156,6 @@ class Config(object):
         """
 
         # VERBOSE("Load config")
-
         self.config_path = Path(path_expand(config_path or self.location.config())).resolve()
 
         self.config_folder = dirname(self.config_path)
@@ -214,6 +168,7 @@ class Config(object):
             content = self.spec_replace(content)
             self.data = yaml.load(content, Loader=yaml.SafeLoader)
 
+
         # print (self.data["cloudmesh"].keys())
 
         # self.data is loaded as nested OrderedDict, can not use set or get
@@ -228,7 +183,8 @@ class Config(object):
         # populate default variables
         #
 
-        self.variable_database = Variables(filename="~/.cloudmesh/var-data")
+        self.variable_database = Variables(filename="~/.cloudmesh/variable.dat")
+
         self.set_debug_defaults()
 
         default = self.default()
@@ -236,6 +192,7 @@ class Config(object):
         for name in self.default():
             if name not in self.variable_database:
                 self.variable_database[name] = default[name]
+
         if "cloud" in default:
             self.cloud = default["cloud"]
         else:
